from PIL import Image, ImageDraw, ImageFont
import os

def create_app_icon():
    # 创建一个512x512的图像（ICO推荐尺寸）
    size = 512
    image = Image.new('RGBA', (size, size), (0, 0, 0, 0))
    draw = ImageDraw.Draw(image)
    
    # 绘制圆形背景
    background_color = (52, 152, 219)  # 使用漂亮的蓝色
    draw.ellipse([10, 10, size-10, size-10], fill=background_color)
    
    # 绘制PDF文字
    text_color = (255, 255, 255)
    font_size = size // 4
    try:
        # 尝试使用Arial字体，如果系统没有则使用默认字体
        font = ImageFont.truetype("arial.ttf", font_size)
    except:
        font = ImageFont.load_default()
    
    text = "PDF"
    # 获取文字大小以居中显示
    text_bbox = draw.textbbox((0, 0), text, font=font)
    text_width = text_bbox[2] - text_bbox[0]
    text_height = text_bbox[3] - text_bbox[1]
    
    x = (size - text_width) // 2
    y = (size - text_height) // 2
    draw.text((x, y), text, font=font, fill=text_color)
    
    # 保存不同尺寸的图标
    icon_sizes = [(16, 16), (32, 32), (48, 48), (64, 64), (128, 128), (256, 256)]
    icon_images = []
    
    for icon_size in icon_sizes:
        resized_image = image.resize(icon_size, Image.Resampling.LANCZOS)
        icon_images.append(resized_image)
    
    # 确保resources/icons目录存在
    icons_dir = os.path.dirname(os.path.abspath(__file__))
    icons_path = os.path.join(icons_dir, 'icons')
    os.makedirs(icons_path, exist_ok=True)
    
    # 保存ICO文件
    icon_path = os.path.join(icons_path, 'app.ico')
    icon_images[0].save(
        icon_path,
        format='ICO',
        sizes=icon_sizes,
        append_images=icon_images[1:]
    )
    
    print(f"图标已创建: {icon_path}")

if __name__ == "__main__":
    create_app_icon()